@@ -6,10 +6,10 @@
 # Input:		Java Keystore
 # Output:		Key pair as array of strings
 # ==============================================================================
-from anaplan_api import jks
+import jks
 import logging
 from base64 import b64encode
-from anaplan_api.jks.util import BadKeystoreFormatException, UnsupportedKeystoreVersionException, KeystoreSignatureException, \
+from jks.util import BadKeystoreFormatException, UnsupportedKeystoreVersionException, KeystoreSignatureException, \
 	DuplicateAliasException, DecryptionFailureException, UnexpectedAlgorithmException
 
 logger = logging.getLogger(__name__)
